Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(172)

Unified Diff: chrome/browser/sync/engine/download_updates_command.h

Issue 386030: Relieve SyncerSession,SyncCycleState, SyncProcessState, SyncerSession, Syncer... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/engine/download_updates_command.h
===================================================================
--- chrome/browser/sync/engine/download_updates_command.h (revision 32731)
+++ chrome/browser/sync/engine/download_updates_command.h (working copy)
@@ -7,17 +7,18 @@
#include "base/basictypes.h"
#include "chrome/browser/sync/engine/syncer_command.h"
-#include "chrome/browser/sync/engine/syncer_session.h"
namespace browser_sync {
// Downloads updates from the server and places them in the SyncerSession.
class DownloadUpdatesCommand : public SyncerCommand {
public:
DownloadUpdatesCommand();
virtual ~DownloadUpdatesCommand();
- virtual void ExecuteImpl(SyncerSession* session);
+ // SyncerCommand implementation.
+ virtual void ExecuteImpl(sessions::SyncSession* session);
+
private:
DISALLOW_COPY_AND_ASSIGN(DownloadUpdatesCommand);
};
@@ -7,17 +7,18 @@
namespace browser_sync {
-// Downloads updates from the server and places them in the SyncerSession.
+// Downloads updates from the server and places them in the SyncSession.
class DownloadUpdatesCommand : public SyncerCommand {
public:
« no previous file with comments | « chrome/browser/sync/engine/conflict_resolver.cc ('k') | chrome/browser/sync/engine/download_updates_command.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698